#!/bin/sh
#
#           ICEFLOOR 2
#
#      pf frontend for OS X
#
#        www.hanynet.com
#
#        by Hany El Imam
#
# Emerging Threats Autoupdate script 4.0.2(pflists) by T. Thonhauser
#
# this script downloads a new updated IP list from a web site
# and updates PF table <emergingthreats> in PF path
# 
# all ipv4 and ipv6 network traffic from/to those hosts will be blocked by PF
# on all network interfaces except loopback interface
# this script is optionally installed by IceFloor or PFLists
# it is run by launchd; .plist file should be stored in
# /Library/LaunchDaemons/com.hanynet.pflists.emergingthreats.plist 
# IceFloor and PFLists are free OS X PF firewall frontends available at www.hanynet.com
# Emerging Threats IP list is NOT provided by hanynet.com .
#
########################################################################

# Thanks to T. Thonhauser for contributing this script

#
# Define some basics
#
url="http://rules.emergingthreats.net/fwrules/emerging-Block-IPs.txt"
anchor=/Library/PFLists/pflists.ettable
tmpfile=/tmp/et_download_file
badIPs=/tmp/et_bad_IPs

#
# We need to trap on TERM signals, according to Apple's launchd docs
#
trap 'exit 1' 15

#
# Use the "ipconfig waitall" command to wait for all the interfaces to come up
#
ipconfig waitall

#
# Sleep a little to give the interface time to connect to the internet
#
sleep 10

#
# Download list and perform error handling
#
rm -f $tmpfile
curl $url > $tmpfile
length=`wc -l $tmpfile | awk '{ print $1 }'`

if [ $length -lt 1000 ]; then
  syslog -s -l 1 icefloor_et.sh: PFLists: Installation of Emerging Threats IP table failed!
  exit 1
fi

#
# Assemble the list of IPs
#
sed -n '/^[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}/p' $tmpfile | tr "\n" " " > $badIPs
echo "# Emerging Threats IP download date: `date`" > $anchor
printf "%s" "table <emergingthreats> { " >> $anchor
cat $badIPs >> $anchor
echo " } persist" >> $anchor

#
# Flush the table and load a new one into PF
#
pfctl -t emergingthreats -T flush
pfctl -t emergingthreats -T add `cat $badIPs`

#
# Clean up and logging
#
rm -f $badIPs $tmpfile
syslog -s -l 1 pflists_emergingthreats.sh: PFLists: Downloaded Emerging Threats IP table.

exit 0
########################################################################




